==> mili-3.9.0.tgz: package/es/src/class/repository/local-repository.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import git from 'simple-git/promise';
import semver from 'semver';
import { relative, join, isAbsolute, basename } from 'path';
import { Repository } from "./repository";
import { TEMPLATE_STORAGE } from "../../consts";
import { logger, dirExist, isRootDirOfRepo, isRelativePath } from "../../utils";
import { Effect } from "../../internal";
export class LocalRepository extends Repository {
    constructor(str) {
        super();
        this.absolute = false;
        this.type = 'local';
        this.name = basename(str);
        const path = str;
        const cwd = process.cwd();
        if (isAbsolute(path)) {
            this.absolute = true;
            this.path = path;
        }
        else {
            this.path = join(cwd, path);
        }
    }
    get record() {
        if (this.absolute)
            return this.path;
        /** the path saved in .milirc should be relative to the output folder, rather than process.cwd() */
        return projectPath => {
            const relativePath = relative(projectPath, this.path);
            if (isRelativePath(relativePath))
                return relativePath;
            else
                return `./${relativePath}`;
        };
    }
    get storage() {
        return join(TEMPLATE_STORAGE, encodeURIComponent(this.path), this.version || 'noversion');
    }
    getVersions() {
        return __awaiter(this, void 0, void 0, function* () {
            const { path } = this;
            if (this.versions)
                return this.versions;
            if (!(yield git(path).checkIsRepo()) || !(yield isRootDirOfRepo(path))) {
                this.versions = [];
                return this.versions;
            }
            const tags = yield git(path).tags();
            if (!tags.all.length) {
                logger.warn([
                    'Cannot get template versions, May be caused by the following reasons:',
                    `1. repository is not a mili template(${path})`,
                    '2. template have not a valid tag to mark the version(e.g. v1.0.0)',
                    `3. cannot get versions by command: \`git tags ${path}\``,
                ].join('\n'));
            }
            this.versions = tags.all
                .map(tag => semver.clean(tag) || '')
                .filter(tag => Boolean(tag))
                .reverse();
            return this.versions;
        });
    }
    download() {
        return __awaiter(this, void 0, void 0, function* () {
            const { path, version, storage } = this;
            yield Effect.fs.emptyDir(storage);
            logger.info(`copy template from ${path}`);
            yield Effect.fs.copy(path, storage);
            if (isRootDirOfRepo(storage) && version && version !== 'default') {
                yield git(storage).reset('hard');
                yield git(storage).checkout(`v${version}`);
                logger.info(`template version: ${version}`);
            }
            else if (version !== 'default') {
                logger.warn('Version is unset, use the default files');
            }
        });
    }
    existed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dirExist(this.path);
        });
    }
}

==> mili-3.9.1.tgz: package/es/src/class/repository/local-repository.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import git from 'simple-git/promise';
import semver from 'semver';
import { relative, join, isAbsolute, basename } from 'path';
import { Repository } from "./repository";
import { TEMPLATE_STORAGE } from "../../consts";
import { logger, dirExist, isRootDirOfRepo, isRelativePath } from "../../utils";
import { Effect } from "../../internal";
import { ResetMode } from 'simple-git';
export class LocalRepository extends Repository {
    constructor(str) {
        super();
        this.absolute = false;
        this.type = 'local';
        this.name = basename(str);
        const path = str;
        const cwd = process.cwd();
        if (isAbsolute(path)) {
            this.absolute = true;
            this.path = path;
        }
        else {
            this.path = join(cwd, path);
        }
    }
    get record() {
        if (this.absolute)
            return this.path;
        /** the path saved in .milirc should be relative to the output folder, rather than process.cwd() */
        return projectPath => {
            const relativePath = relative(projectPath, this.path);
            if (isRelativePath(relativePath))
                return relativePath;
            else
                return `./${relativePath}`;
        };
    }
    get storage() {
        return join(TEMPLATE_STORAGE, encodeURIComponent(this.path), this.version || 'noversion');
    }
    getVersions() {
        return __awaiter(this, void 0, void 0, function* () {
            const { path } = this;
            if (this.versions)
                return this.versions;
            if (!(yield git(path).checkIsRepo()) || !(yield isRootDirOfRepo(path))) {
                this.versions = [];
                return this.versions;
            }
            const tags = yield git(path).tags();
            if (!tags.all.length) {
                logger.warn([
                    'Cannot get template versions, May be caused by the following reasons:',
                    `1. repository is not a mili template(${path})`,
                    '2. template have not a valid tag to mark the version(e.g. v1.0.0)',
                    `3. cannot get versions by command: \`git tags ${path}\``,
                ].join('\n'));
            }
            this.versions = tags.all
                .map(tag => semver.clean(tag) || '')
                .filter(tag => Boolean(tag))
                .reverse();
            return this.versions;
        });
    }
    download() {
        return __awaiter(this, void 0, void 0, function* () {
            const { path, version, storage } = this;
            yield Effect.fs.emptyDir(storage);
            logger.info(`copy template from ${path}`);
            yield Effect.fs.copy(path, storage);
            if (isRootDirOfRepo(storage) && version && version !== 'default') {
                yield git(storage).reset(ResetMode.HARD);
                yield git(storage).checkout(`v${version}`);
                logger.info(`template version: ${version}`);
            }
            else if (version !== 'default') {
                logger.warn('Version is unset, use the default files');
            }
        });
    }
    existed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dirExist(this.path);
        });
    }
}
